package com.sundot.airport.blocked.service;

import java.util.List;

import com.sundot.airport.blocked.domain.BlockedLuggageStatisticsDaily;

/**
 * 每日行李过检查堵统计Service接口
 *
 * @author wangxx
 * @date 2026-04-13
 */
public interface IBlockedLuggageStatisticsDailyService {
    /**
     * 查询每日行李过检查堵统计
     *
     * @param id 每日行李过检查堵统计主键
     * @return 每日行李过检查堵统计
     */
    public BlockedLuggageStatisticsDaily selectBlockedLuggageStatisticsDailyById(Long id);

    /**
     * 查询每日行李过检查堵统计列表
     *
     * @param blockedLuggageStatisticsDaily 每日行李过检查堵统计
     * @return 每日行李过检查堵统计集合
     */
    public List<BlockedLuggageStatisticsDaily> selectBlockedLuggageStatisticsDailyList(BlockedLuggageStatisticsDaily blockedLuggageStatisticsDaily);

    /**
     * 新增每日行李过检查堵统计
     *
     * @param blockedLuggageStatisticsDaily 每日行李过检查堵统计
     * @return 结果
     */
    public int insertBlockedLuggageStatisticsDaily(BlockedLuggageStatisticsDaily blockedLuggageStatisticsDaily);

    /**
     * 修改每日行李过检查堵统计
     *
     * @param blockedLuggageStatisticsDaily 每日行李过检查堵统计
     * @return 结果
     */
    public int updateBlockedLuggageStatisticsDaily(BlockedLuggageStatisticsDaily blockedLuggageStatisticsDaily);

    /**
     * 批量删除每日行李过检查堵统计
     *
     * @param ids 需要删除的每日行李过检查堵统计主键集合
     * @return 结果
     */
    public int deleteBlockedLuggageStatisticsDailyByIds(Long[] ids);

    /**
     * 删除每日行李过检查堵统计信息
     *
     * @param id 每日行李过检查堵统计主键
     * @return 结果
     */
    public int deleteBlockedLuggageStatisticsDailyById(Long id);

    /**
     * 导入每日行李过检查堵统计数据
     *
     * @param list 数据列表
     * @param updateSupport 是否更新支持
     * @return 导入结果信息
     */
    public String importData(List<BlockedLuggageStatisticsDaily> list, boolean updateSupport);

    /**
     * 检查数据是否重复
     *
     * @param blockedLuggageStatisticsDaily 统计数据
     * @return 重复的数据，如果没有重复返回null
     */
    public BlockedLuggageStatisticsDaily checkDuplicate(BlockedLuggageStatisticsDaily blockedLuggageStatisticsDaily);

    /**
     * 新增或更新每日行李过检查堵统计（如果数据重复则覆盖更新）
     *
     * @param blockedLuggageStatisticsDaily 每日行李过检查堵统计
     * @return 结果
     */
    public int insertOrUpdate(BlockedLuggageStatisticsDaily blockedLuggageStatisticsDaily);
}
